@@ -36,18 +36,34 @@ class Entity(object):
 
 
 class Account(Entity):
+    """
+    Entity properties:
+    https://alpaca.markets/docs/api-documentation/api-v2/account/
+    """
     pass
 
 
 class AccountConfigurations(Entity):
+    """
+    Entity properties:
+    https://alpaca.markets/docs/api-documentation/api-v2/account-configuration/
+    """
     pass
 
 
 class Asset(Entity):
+    """
+    Entity properties:
+    https://alpaca.markets/docs/api-documentation/api-v2/assets/#asset-entity
+    """
     pass
 
 
 class Order(Entity):
+    """
+    Entity properties:
+    https://alpaca.markets/docs/api-documentation/api-v2/orders/#order-entity
+    """
     def __init__(self, raw):
         super().__init__(raw)
         try:
@@ -58,14 +74,27 @@ class Order(Entity):
 
 
 class Position(Entity):
+    """
+    Entity properties:
+https://alpaca.markets/docs/api-documentation/api-v2/positions/#position-entity
+    """
     pass
 
 
 class AccountActivity(Entity):
+    """
+    Entity properties:
+    https://alpaca.markets/docs/api-documentation/api-v2/account-activities/
+    """
     pass
 
 
 class Bar(Entity):
+    """
+    Entity properties:
+    https://alpaca.markets/docs/api-documentation/api-v2/market-data/bars/
+    #bars-entity
+    """
     def __getattr__(self, key):
         if key == 't':
             val = self._raw[key[0]]
@@ -150,6 +179,10 @@ class _MilliTimestamped(_Timestamped):
 
 
 class Agg(_MilliTimestamped, Entity):
+    """
+    Entity properties:
+    https://alpaca.markets/docs/api-documentation/api-v2/market-data/streaming/
+    """
     _tskeys = ('timestamp', 'start', 'end')
 
 
@@ -200,10 +233,20 @@ class Trade(_NanoTimestamped, Entity):
 
 
 class Quote(_NanoTimestamped, Entity):
+    """
+    Entity properties:
+    https://alpaca.markets/docs/api-documentation/api-v2/market-data/last-quote
+    /#last-quote-entity
+    """
     pass
 
 
 class Clock(Entity):
+    """
+    Entity properties:
+    https://alpaca.markets/docs/api-documentation/api-v2/clock/#clock-entity
+    """
+
     def __getattr__(self, key):
         if key in self._raw:
             val = self._raw[key]
@@ -215,6 +258,11 @@ class Clock(Entity):
 
 
 class Calendar(Entity):
+    """
+    Entity properties:
+    https://alpaca.markets/docs/api-documentation/api-v2/calendar/
+    #calendar-entity
+    """
     def __getattr__(self, key):
         if key in self._raw:
             val = self._raw[key]
@@ -228,10 +276,20 @@ class Calendar(Entity):
 
 
 class Watchlist(Entity):
+    """
+    Entity properties:
+    https://alpaca.markets/docs/api-documentation/api-v2/watchlist/
+    #watchlist-entity
+    """
     pass
 
 
 class PortfolioHistory(Entity):
+    """
+    Entity properties:
+    https://alpaca.markets/docs/api-documentation/api-v2/portfolio-history/
+    #portfoliohistory-entity
+    """
     def __init__(self, raw):
         self._raw = raw
 
