@@ -7,6 +7,10 @@ NY = 'America/New_York'
 class Entity(object):
     def __init__(self, raw):
         self._raw = raw
+        if 'from' in self._raw:
+            # can't use python keyword 'from'. if the api returns it,
+            # we switch it to _from, which is usable for the users.
+            self._raw['_from'] = self._raw['from']
 
     def __getattr__(self, key):
         if key in self._raw:
@@ -89,7 +93,14 @@ class Aggsv2(list):
         ])
 
     def _raw_results(self):
-        return self._raw.get('results', [])
+        results = self._raw.get('results')
+        if not results:
+            # this is not very pythonic but it's written like this because
+            # the raw response for empty aggs was None, and this:
+            # self._raw.get('results', []) returns None, not [] which breaks
+            # when we try to iterate it.
+            return []
+        return results
 
     def rename_keys(self):
         colmap = {
@@ -99,6 +110,7 @@ class Aggsv2(list):
             "c": "close",
             "v": "volume",
             "t": "timestamp",
+            "vw": "vwap",
         }
 
         return [
@@ -109,7 +121,8 @@ class Aggsv2(list):
     @property
     def df(self):
         if not hasattr(self, '_df'):
-            columns = ('timestamp', 'open', 'high', 'low', 'close', 'volume')
+            columns = ('timestamp', 'open', 'high', 'low', 'close',
+                       'volume', 'vwap')
             df = pd.DataFrame(
                 self.rename_keys(),
                 columns=columns
@@ -316,6 +329,10 @@ class Ticker(Entity):
     pass
 
 
+class Symbol(Entity):
+    pass
+
+
 class DailyOpenClose(Entity):
     pass
 
