@@ -6,18 +6,19 @@ import os
 import websockets
 from .entity import (
     Quote, Trade, Agg, Entity,
+    trade_mapping, quote_mapping, agg_mapping
 )
-from alpaca_trade_api.common import get_polygon_credentials
+from alpaca_trade_api.common import get_polygon_credentials, URL
 import logging
 
 
 class StreamConn(object):
-    def __init__(self, key_id=None):
+    def __init__(self, key_id: str = None):
         self._key_id = get_polygon_credentials(key_id)
-        self._endpoint = os.environ.get(
+        self._endpoint: URL = URL(os.environ.get(
             'POLYGON_WS_URL',
-            'wss://alpaca.socket.polygon.io/stocks'
-        ).rstrip('/')
+            'wss://socket.polygon.io/stocks'
+        ).rstrip('/'))
         self._handlers = {}
         self._handler_symbols = {}
         self._streams = set([])
@@ -26,6 +27,7 @@ class StreamConn(object):
         self._retry_wait = int(os.environ.get('APCA_RETRY_WAIT', 3))
         self._retries = 0
         self.loop = asyncio.get_event_loop()
+        self._consume_task = None
 
     async def connect(self):
         await self._dispatch({'ev': 'status',
@@ -41,8 +43,9 @@ class StreamConn(object):
                     .format(msg))
             )
         await self._dispatch(msg)
+        logging.info(f"connected to: {self._endpoint}")
         if await self.authenticate():
-            asyncio.ensure_future(self._consume_msg())
+            self._consume_task = asyncio.ensure_future(self._consume_msg())
         else:
             await self.close()
 
@@ -96,6 +99,10 @@ class StreamConn(object):
             await self.close()
             asyncio.ensure_future(self._ensure_ws())
 
+    async def consume(self):
+        if self._consume_task:
+            await self._consume_task
+
     async def _consume_msg(self):
         async for data in self._stream:
             stream = data.get('ev')
@@ -106,8 +113,8 @@ class StreamConn(object):
                 data['ev'] = 'status'
                 await self._dispatch(data)
                 raise ConnectionResetError(
-                        'Polygon terminated connection: '
-                        f'({data.get("message")})')
+                    'Polygon terminated connection: '
+                    f'({data.get("message")})')
 
     async def _ensure_ws(self):
         if self._ws is not None:
@@ -179,56 +186,23 @@ class StreamConn(object):
 
     async def close(self):
         '''Close any open connections'''
+        if self._consume_task:
+            self._consume_task.cancel()
         if self._ws is not None:
             await self._ws.close()
         self._ws = None
 
     def _cast(self, subject, data):
         if subject == 'T':
-            map = {
-                "sym": "symbol",
-                "c": "conditions",
-                "x": "exchange",
-                "p": "price",
-                "s": "size",
-                "t": "timestamp"
-            }
-            ent = Trade({map[k]: v for k, v in data.items() if k in map})
-        elif subject == 'Q':
-            map = {
-                "sym": "symbol",
-                "ax": "askexchange",
-                "ap": "askprice",
-                "as": "asksize",
-                "bx": "bidexchange",
-                "bp": "bidprice",
-                "bs": "bidsize",
-                "c": "condition",
-                "t": "timestamp"
-            }
-            ent = Quote({map[k]: v for k, v in data.items() if k in map})
-        elif subject == 'AM' or subject == 'A':
-            map = {
-                "sym": "symbol",
-                "a": "average",
-                "c": "close",
-                "h": "high",
-                "k": "transactions",
-                "l": "low",
-                "o": "open",
-                "t": "totalvalue",
-                "x": "exchange",
-                "v": "volume",
-                "s": "start",
-                "e": "end",
-                "vw": "vwap",
-                "av": "totalvolume",
-                "op": "dailyopen",    # depricated? stream often has 0 for op
-            }
-            ent = Agg({map[k]: v for k, v in data.items() if k in map})
-        else:
-            ent = Entity(data)
-        return ent
+            return Trade({trade_mapping[k]: v for k,
+                          v in data.items() if k in trade_mapping})
+        if subject == 'Q':
+            return Quote({quote_mapping[k]: v for k,
+                          v in data.items() if k in quote_mapping})
+        if subject == 'AM' or subject == 'A':
+            return Agg({agg_mapping[k]: v for k,
+                        v in data.items() if k in agg_mapping})
+        return Entity(data)
 
     async def _dispatch(self, msg):
         channel = msg.get('ev')
